==> sparkling-water-ml_2.11-3.32.1.5-1-2.2-sources.jar: ai/h2o/sparkling/ml/params/H2OGridSearchCartesianCriteriaParams.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.params

import hex.grid.HyperSpaceSearchCriteria.CartesianSearchCriteria
import ai.h2o.sparkling.H2OFrame

trait H2OGridSearchCartesianCriteriaParams
  extends H2OAlgoParamsBase {


  //
  // Parameter definitions
  //


  //
  // Default values
  //
  setDefault(
)

  //
  // Getters
  //


  //
  // Setters
  //


  override private[sparkling] def getH2OAlgorithmParams(trainingFrame: H2OFrame): Map[String, Any] = {
    super.getH2OAlgorithmParams(trainingFrame) ++ getH2OGridSearchCartesianCriteriaParams(trainingFrame)
  }

  private[sparkling] def getH2OGridSearchCartesianCriteriaParams(trainingFrame: H2OFrame): Map[String, Any] = {
      Map(
)
  }

  override private[sparkling] def getSWtoH2OParamNameMap(): Map[String, String] = {
    super.getSWtoH2OParamNameMap() ++
      Map(
)
  }
      
}

==> sparkling-water-ml_2.12-3.32.1.1-1-3.0-sources.jar: ai/h2o/sparkling/ml/params/H2OGridSearchCartesianCriteriaParams.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ai.h2o.sparkling.ml.params

import hex.grid.HyperSpaceSearchCriteria.CartesianSearchCriteria
import ai.h2o.sparkling.H2OFrame

trait H2OGridSearchCartesianCriteriaParams
  extends H2OAlgoParamsBase {


  //
  // Parameter definitions
  //


  //
  // Default values
  //
  setDefault(
)

  //
  // Getters
  //


  //
  // Setters
  //


  override private[sparkling] def getH2OAlgorithmParams(trainingFrame: H2OFrame): Map[String, Any] = {
    super.getH2OAlgorithmParams(trainingFrame) ++ getH2OGridSearchCartesianCriteriaParams()
  }

  private[sparkling] def getH2OGridSearchCartesianCriteriaParams(): Map[String, Any] = {
      Map(
)
  }

  override private[sparkling] def getSWtoH2OParamNameMap(): Map[String, String] = {
    super.getSWtoH2OParamNameMap() ++
      Map(
)
  }
      
}
